@@ -1,6 +1,11 @@
 #ifndef WAVINFO_H
 #define WAVINFO_H
 
+#include <QObject>
+#include <QtGlobal>
+#include <QString>
+
+
 typedef struct {
                 char chunk_id[4];
                 quint32 chunk_size;
